@@ -18,7 +18,6 @@ atk_hyperlink_state_flags_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "atkobject.h" */
 GType
 atk_role_get_type (void)
@@ -100,6 +99,9 @@ atk_role_get_type (void)
       { ATK_ROLE_PARAGRAPH, "ATK_ROLE_PARAGRAPH", "paragraph" },
       { ATK_ROLE_RULER, "ATK_ROLE_RULER", "ruler" },
       { ATK_ROLE_APPLICATION, "ATK_ROLE_APPLICATION", "application" },
+      { ATK_ROLE_AUTOCOMPLETE, "ATK_ROLE_AUTOCOMPLETE", "autocomplete" },
+      { ATK_ROLE_EDITBAR, "ATK_ROLE_EDITBAR", "editbar" },
+      { ATK_ROLE_EMBEDDED, "ATK_ROLE_EMBEDDED", "embedded" },
       { ATK_ROLE_LAST_DEFINED, "ATK_ROLE_LAST_DEFINED", "last-defined" },
       { 0, NULL, NULL }
     };
@@ -107,7 +109,6 @@ atk_role_get_type (void)
   }
   return etype;
 }
-
 GType
 atk_layer_get_type (void)
 {
@@ -129,7 +130,6 @@ atk_layer_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "atkrelationtype.h" */
 GType
 atk_relation_type_get_type (void)
@@ -149,6 +149,8 @@ atk_relation_type_get_type (void)
       { ATK_RELATION_SUBWINDOW_OF, "ATK_RELATION_SUBWINDOW_OF", "subwindow-of" },
       { ATK_RELATION_EMBEDS, "ATK_RELATION_EMBEDS", "embeds" },
       { ATK_RELATION_EMBEDDED_BY, "ATK_RELATION_EMBEDDED_BY", "embedded-by" },
+      { ATK_RELATION_POPUP_FOR, "ATK_RELATION_POPUP_FOR", "popup-for" },
+      { ATK_RELATION_PARENT_WINDOW_OF, "ATK_RELATION_PARENT_WINDOW_OF", "parent-window-of" },
       { ATK_RELATION_LAST_DEFINED, "ATK_RELATION_LAST_DEFINED", "last-defined" },
       { 0, NULL, NULL }
     };
@@ -157,7 +159,6 @@ atk_relation_type_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "atkstate.h" */
 GType
 atk_state_type_get_type (void)
@@ -195,6 +196,9 @@ atk_state_type_get_type (void)
       { ATK_STATE_VERTICAL, "ATK_STATE_VERTICAL", "vertical" },
       { ATK_STATE_VISIBLE, "ATK_STATE_VISIBLE", "visible" },
       { ATK_STATE_MANAGES_DESCENDANTS, "ATK_STATE_MANAGES_DESCENDANTS", "manages-descendants" },
+      { ATK_STATE_INDETERMINATE, "ATK_STATE_INDETERMINATE", "indeterminate" },
+      { ATK_STATE_TRUNCATED, "ATK_STATE_TRUNCATED", "truncated" },
+      { ATK_STATE_REQUIRED, "ATK_STATE_REQUIRED", "required" },
       { ATK_STATE_LAST_DEFINED, "ATK_STATE_LAST_DEFINED", "last-defined" },
       { 0, NULL, NULL }
     };
@@ -203,7 +207,6 @@ atk_state_type_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "atktext.h" */
 GType
 atk_text_attribute_get_type (void)
@@ -246,7 +249,6 @@ atk_text_attribute_get_type (void)
   }
   return etype;
 }
-
 GType
 atk_text_boundary_get_type (void)
 {
@@ -266,7 +268,6 @@ atk_text_boundary_get_type (void)
   }
   return etype;
 }
-
 GType
 atk_text_clip_type_get_type (void)
 {
@@ -284,7 +285,6 @@ atk_text_clip_type_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "atkutil.h" */
 GType
 atk_key_event_type_get_type (void)
@@ -301,7 +301,6 @@ atk_key_event_type_get_type (void)
   }
   return etype;
 }
-
 GType
 atk_coord_type_get_type (void)
 {
@@ -317,6 +316,5 @@ atk_coord_type_get_type (void)
   return etype;
 }
 
-
 /* Generated data ends here */
 
