@@ -19,7 +19,6 @@
 
 #include "atkutil.h"
 #include "atkmarshal.c"
-#include "config.h"
 
 static void atk_util_class_init (AtkUtilClass *klass);
 
@@ -82,7 +81,7 @@ struct _FocusTracker {
 
 /**
  * atk_focus_tracker_init:
- * @init: Function to be called for focus tracker initialization
+ * @add_function: Function to be called for focus tracker initialization
  *
  * Specifies the function to be called for focus tracker initialization.
  * This function should be called by an implementation of the
@@ -227,7 +226,7 @@ atk_add_global_event_listener (GSignalEmissionHook listener,
     }
   else
     {
-      retval = 0;
+      retval = -1;
     }
   g_type_class_unref (klass);
 
@@ -272,7 +271,7 @@ atk_add_key_event_listener (AtkKeySnoopFunc listener, gpointer data)
     }
   else
     {
-      retval = 0;
+      retval = -1;
     }
 
   return retval;
@@ -322,8 +321,6 @@ atk_get_root (void)
  * atk_get_focus_object:
  *
  * Gets the currently focused object.
- * 
- * Since: 1.6
  *
  * Returns: the currently focused object for the current application
  **/
@@ -382,18 +379,3 @@ atk_get_toolkit_version (void)
 
   return retval;
 }
-
-/**
- * atk_get_version:
- *
- * Gets the current version for ATK.
- *
- * Returns: version string for ATK
- **/
-
-G_CONST_RETURN gchar *
-atk_get_version (void)
-{
-  return VERSION;
-}
-
